==> telegram-desktop_3.6.1+ds.orig.tar.xz: tdesktop-3.6.1-full/Telegram/lib_ui/ui/style/style_core_scale.h <==
// This file is part of Desktop App Toolkit,
// a set of libraries for developing nice desktop applications.
//
// For license and copyright information please follow this link:
// https://github.com/desktop-app/legal/blob/master/LEGAL
//
#pragma once

#include "base/algorithm.h"

#include <QtCore/QSize>

#include <algorithm>
#include <cmath>

namespace style {

inline constexpr auto kScaleAuto = 0;
inline constexpr auto kScaleMin = 75;
inline constexpr auto kScaleDefault = 100;
inline constexpr auto kScaleMax = 300;

[[nodiscard]] int DevicePixelRatio();
void SetDevicePixelRatio(int ratio);

[[nodiscard]] int Scale();
void SetScale(int scale);

[[nodiscard]] inline int CheckScale(int scale) {
	return (scale == kScaleAuto)
		? kScaleAuto
		: std::clamp(scale, kScaleMin, kScaleMax / DevicePixelRatio());
}

template <typename T>
[[nodiscard]] inline T ConvertScale(T value, int scale) {
	return (value < 0.)
		? (-ConvertScale(-value, scale))
		: T(base::SafeRound((double(value) * scale / 100.) - 0.01));
}

template <typename T>
[[nodiscard]] inline T ConvertScale(T value) {
	return ConvertScale(value, Scale());
}

template <typename T>
[[nodiscard]] inline T ConvertScaleExact(T value, int scale) {
	return (value < 0.)
		? (-ConvertScale(-value, scale))
		: T(double(value) * scale / 100.);
}

template <typename T>
[[nodiscard]] inline T ConvertScaleExact(T value) {
	return ConvertScaleExact(value, Scale());
}

[[nodiscard]] inline QSize ConvertScale(QSize size) {
	return QSize(ConvertScale(size.width()), ConvertScale(size.height()));
}

} // namespace style

==> telegram-desktop_4.6.5+ds.orig.tar.xz: tdesktop-4.6.5-full/Telegram/lib_ui/ui/style/style_core_scale.h <==
// This file is part of Desktop App Toolkit,
// a set of libraries for developing nice desktop applications.
//
// For license and copyright information please follow this link:
// https://github.com/desktop-app/legal/blob/master/LEGAL
//
#pragma once

#include "base/algorithm.h"

#include <QtCore/QSize>

#include <algorithm>
#include <cmath>

namespace style {

inline constexpr auto kScaleAuto = 0;
inline constexpr auto kScaleMin = 50;
inline constexpr auto kScaleDefault = 100;
inline constexpr auto kScaleMax = 300;

[[nodiscard]] int DevicePixelRatio();
void SetDevicePixelRatio(int ratio);

[[nodiscard]] int Scale();
void SetScale(int scale);

[[nodiscard]] inline int CheckScale(int scale) {
	return (scale == kScaleAuto)
		? kScaleAuto
		: std::clamp(scale, kScaleMin, kScaleMax / DevicePixelRatio());
}

template <typename T>
[[nodiscard]] inline T ConvertScale(T value, int scale) {
	if (value < 0.) {
		return -ConvertScale(-value, scale);
	}
	const auto result = T(base::SafeRound(
		(double(value) * scale / 100.) - 0.01));
	return (!std::is_integral_v<T> || !value || result) ? result : 1;
}

template <typename T>
[[nodiscard]] inline T ConvertScale(T value) {
	return ConvertScale(value, Scale());
}

template <typename T>
[[nodiscard]] inline T ConvertScaleExact(T value, int scale) {
	return (value < 0.)
		? (-ConvertScale(-value, scale))
		: T(double(value) * scale / 100.);
}

template <typename T>
[[nodiscard]] inline T ConvertScaleExact(T value) {
	return ConvertScaleExact(value, Scale());
}

[[nodiscard]] inline QSize ConvertScale(QSize size) {
	return QSize(ConvertScale(size.width()), ConvertScale(size.height()));
}

} // namespace style
